
# Class: physical essence


Semantic mixin concept.  Pertains to entities that have physical properties such as mass, volume, or charge.

URI: [biolink:PhysicalEssence](https://w3id.org/biolink/vocab/PhysicalEssence)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[PhysicalEssenceOrOccurrent],[PhysicalEntity]uses%20-.->[PhysicalEssence],[MolecularEntity]uses%20-.->[PhysicalEssence],[AnatomicalEntity]uses%20-.->[PhysicalEssence],[PhysicalEssenceOrOccurrent]^-[PhysicalEssence],[PhysicalEntity],[MolecularEntity],[AnatomicalEntity])](https://yuml.me/diagram/nofunky;dir:TB/class/[PhysicalEssenceOrOccurrent],[PhysicalEntity]uses%20-.->[PhysicalEssence],[MolecularEntity]uses%20-.->[PhysicalEssence],[AnatomicalEntity]uses%20-.->[PhysicalEssence],[PhysicalEssenceOrOccurrent]^-[PhysicalEssence],[PhysicalEntity],[MolecularEntity],[AnatomicalEntity])

## Parents

 *  is_a: [PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md) - Either a physical or processual entity.

## Mixin for

 * [AnatomicalEntity](AnatomicalEntity.md) (mixin)  - A subcellular location, cell type or gross anatomical part
 * [MolecularEntity](MolecularEntity.md) (mixin)  - A gene, gene product, small molecule or macromolecule (including protein complex)"
 * [PhysicalEntity](PhysicalEntity.md) (mixin)  - An entity that has material reality (a.k.a. physical essence).

## Referenced by Class


## Attributes

